@@ -21,6 +21,7 @@ class WorkforceAddressSummary(models.Model):
     state = models.CharField(max_length=50, blank=True, default="", verbose_name="State or Region")
     postal_code = models.CharField(max_length=15, blank=True, default="", verbose_name="Postal or Zip code")
     coords = models.CharField(max_length=40, blank=True)
+
     class Meta:
         managed = model_settings.DATAWAREHOUSE_MANAGED_MODELS
         app_label = 'workforce'
@@ -28,7 +29,6 @@ class WorkforceAddressSummary(models.Model):
         db_table = 'workforce"."address_summary'
 
 
-# Constance settings
 class ConstanceSetting(models.Model):
     slug = models.CharField(max_length=100)
     setting_name = models.TextField()
@@ -42,7 +42,6 @@ class ConstanceSetting(models.Model):
         db_table = 'workforce"."constance_summary'
 
 
-# extensions
 class ExtensionSummary(models.Model):
     tenant = models.CharField(db_index=True, max_length=200)
     name = models.CharField(max_length=100)
@@ -55,7 +54,6 @@ class ExtensionSummary(models.Model):
         db_table = 'workforce"."extension_summary'
 
 
-# featureflags
 class FeatureFlagSummary(models.Model):
     tenant = models.CharField(db_index=True, max_length=200)
     name = models.CharField(max_length=100)
@@ -67,11 +65,8 @@ class FeatureFlagSummary(models.Model):
         default_permissions = ()
         db_table = 'workforce"."featureflag_summary'
 
-# metrics datapoint
 
-# template change request
 class TemplateChangeRequestSummary(models.Model):
-    # fmt: off
     tenant = models.CharField(db_index=True, max_length=200)
     tcr_pk = models.PositiveIntegerField()
     created = models.DateTimeField()
@@ -86,7 +81,6 @@ class TemplateChangeRequestSummary(models.Model):
     template_content_type_model = models.CharField(max_length=200)
     estimated_price = models.PositiveIntegerField()
     estimated_hours = models.DecimalField(decimal_places=4, max_digits=11)
-    # fmt: on
 
     class Meta:
         managed = model_settings.DATAWAREHOUSE_MANAGED_MODELS
@@ -97,9 +91,7 @@ class TemplateChangeRequestSummary(models.Model):
         )
 
 
-# customer_all_users
 class UserSummaryRow(models.Model):
-    # fmt: off
     last_synced = models.DateTimeField(db_index=True)
     tenant = models.CharField(db_index=True, max_length=200)
     user_pk = models.PositiveIntegerField(db_index=True)
@@ -111,7 +103,6 @@ class UserSummaryRow(models.Model):
     created = models.DateTimeField(db_index=True)
     last_access = models.DateTimeField(null=True, blank=True, db_index=True)
     groups = ArrayField(models.CharField(max_length=150), default=list, blank=True)
-    # fmt: on
 
     class Meta:
         managed = model_settings.DATAWAREHOUSE_MANAGED_MODELS
@@ -120,13 +111,10 @@ class UserSummaryRow(models.Model):
         db_table = 'workforce"."customer_all_users'
 
 
-# customer_onboarding_actions
 class OnboardingActionRow(models.Model):
-    # fmt: off
     tenant = models.CharField(db_index=True, max_length=200)
     last_synced = models.DateTimeField(db_index=True)
     is_active = models.BooleanField(db_index=True)
-
     name = models.CharField(max_length=150)
     description = models.TextField(blank=True, default='')
     due_date = models.DateField(blank=True, null=True)
@@ -136,8 +124,6 @@ class OnboardingActionRow(models.Model):
     progress = models.IntegerField(blank=True, null=True)
     effort = models.IntegerField(blank=True, null=True)
     group = models.CharField(max_length=100)
-    # fmt: on
-
 
     class Meta:
         managed = model_settings.DATAWAREHOUSE_MANAGED_MODELS
@@ -156,22 +142,16 @@ class UsageMetrics(models.Model):
         managed = model_settings.DATAWAREHOUSE_MANAGED_MODELS
         app_label = 'workforce'
         db_table = 'workforce"."usage_metrics'
-
         indexes =   [
             models.Index(fields=['tenant', 'count_name', '-as_of'], name='usage_metrics_latest_btree'),
         ]
 
 
 class ServerUsage(models.Model):
-    """Resource usage.
-
-    This is an unmanaged model that lets us easily grab the resources used by the customer
-    for the current billing cycle.
-
-    """
+    """Mechanism for this Workspace to update the datawarehouse with it's resource utilisation for licensing."""
     tenant = models.CharField(max_length=200)
     staff_licenses_total = models.IntegerField()
-    staff_licenses_used = models.IntegerField()  # This is all we're using currently
+    staff_licenses_used = models.IntegerField()
     staff_licenses_additional = models.IntegerField()
     desk_licenses_used = models.IntegerField()
     field_licenses_used = models.IntegerField()
@@ -180,13 +160,13 @@ class ServerUsage(models.Model):
     api_licenses_used = models.IntegerField()
     reporting_licenses_used = models.IntegerField()
     timesheet_licenses_used = models.IntegerField()
+    contractor_addons_used = models.IntegerField(default=0)
     last_synced = models.DateTimeField()
     for_date = models.DateField()
 
     class Meta:
         managed = model_settings.DATAWAREHOUSE_MANAGED_MODELS
         app_label = 'workforce'
-
         default_permissions = ()
         db_table = 'workforce"."licensing_usage'
         unique_together = ('tenant', 'for_date')
